@@ -48,13 +48,13 @@ gbif <- function(genus, species='', ext=NULL, args=NULL, geo=TRUE, sp=FALSE, rem
 	
 	if (! requireNamespace('jsonlite')) { stop('You need to install the jsonlite package to use this function') }
 
-	tmpfile <- paste(tempfile(), '.json', sep='')
+	tmpfile <- paste0(tempfile(), '.json')
 	ex <- .getExtGBIF(ext)
 	spec <- .fixNameGBIF(genus, species)
 	if (sp) geo <- TRUE
 	if (geo) { cds <- '&coordinatestatus=true' } else { cds <- '' }
 
-	base <- "http://api.gbif.org/v1/occurrence/search?"
+	base <- "https://api.gbif.org/v1/occurrence/search?"
 	
 	if (!is.null(args)) {
 		args <- trim(as.character(args))
@@ -192,6 +192,7 @@ gbif <- function(genus, species='', ext=NULL, args=NULL, geo=TRUE, sp=FALSE, rem
 			iso <- ccodes()
 			i <- match(z$ISO2, iso[, 'ISO2'])
 			z$country <- iso[i, 1]
+			z$country[is.na(z$ISO2)] <- NA	
 		}
 		
 		vrs <- c('locality', 'adm1', 'adm2', 'country', 'continent') 
